@@ -129,6 +129,7 @@ static const ComboItem chardet_detector_presets[] = {
 };
 
 static const ComboItem bitdepth_elements[] = {
+    ComboItem (N_("Automatic"), -1),
     ComboItem ("16", 16),
     ComboItem ("24", 24),
     ComboItem ("32", 32),
@@ -164,7 +165,7 @@ static void output_bit_depth_changed ();
 
 static const PreferencesWidget output_combo_widgets[] = {
     WidgetCombo (N_("Output plugin:"),
-        WidgetInt (output_combo_selected, output_combo_changed),
+        WidgetInt (output_combo_selected, output_combo_changed, "audqt update output combo"),
         {0, output_combo_fill}),
     WidgetCustomQt (output_create_config_button),
     WidgetCustomQt (output_create_about_button)
@@ -194,8 +195,8 @@ static const PreferencesWidget audio_page_widgets[] = {
         WidgetBool (0, "soft_clipping")),
     WidgetCheck (N_("Use software volume control (not recommended)"),
         WidgetBool (0, "software_volume_control")),
-    WidgetLabel (N_("<b>Replay Gain</b>")),
-    WidgetCheck (N_("Enable Replay Gain"),
+    WidgetLabel (N_("<b>ReplayGain</b>")),
+    WidgetCheck (N_("Enable ReplayGain"),
         WidgetBool (0, "enable_replay_gain")),
     WidgetCheck (N_("Album mode"),
         WidgetBool (0, "replay_gain_album"),
@@ -270,8 +271,10 @@ static const PreferencesWidget playlist_page_widgets[] = {
     WidgetLabel (N_("<b>Song Display</b>")),
     WidgetCheck (N_("Show song numbers"),
         WidgetBool (0, "show_numbers_in_pl", send_title_change)),
-    WidgetCheck (N_("Show leading zeroes (02:00 instead of 2:00)"),
+    WidgetCheck (N_("Show leading zeroes (02:00 vs. 2:00)"),
         WidgetBool (0, "leading_zero", send_title_change)),
+    WidgetCheck (N_("Show hours separately (1:30:00 vs. 90:00)"),
+        WidgetBool (0, "show_hours", send_title_change)),
     WidgetCustomQt (create_titlestring_table),
     WidgetLabel (N_("<b>Compatibility</b>")),
     WidgetCheck (N_("Interpret \\ (backward slash) as a folder delimiter"),
@@ -367,7 +370,7 @@ static void * create_titlestring_table ()
     }
 
     QObject::connect (le, &QLineEdit::textChanged, [=] (const QString & text) {
-        aud_set_str (nullptr, "generic_title_format", text.toLocal8Bit ().data ());
+        aud_set_str (nullptr, "generic_title_format", text.toUtf8 ().data ());
     });
 
     QObject::connect (cbox,
@@ -469,13 +472,20 @@ static void * iface_create_prefs_box ()
 
 static void output_combo_changed ()
 {
-    PluginHandle * plugin = aud_plugin_list (PluginType::Output)[output_combo_selected];
+    auto & list = aud_plugin_list (PluginType::Output);
+    PluginHandle * plugin = list[output_combo_selected];
 
     if (aud_plugin_enable (plugin, true))
     {
         output_config_button->setEnabled (aud_plugin_has_configure (plugin));
         output_about_button->setEnabled (aud_plugin_has_about (plugin));
     }
+    else
+    {
+        /* set combo box back to current output */
+        output_combo_selected = list.find (aud_plugin_get_current (PluginType::Output));
+        hook_call ("audqt update output combo", nullptr);
+    }
 }
 
 static void * output_create_config_button ()
